@@ -278,7 +278,7 @@ get_proxy_for_iface (Device          *device,
 
 	proxy = g_object_get_data (G_OBJECT (device), interface);
 	if (proxy != NULL)
-		return proxy;
+		return g_object_ref (proxy);
 
 	proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
 					       G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES | G_DBUS_PROXY_FLAGS_DO_NOT_AUTO_START,
@@ -296,7 +296,7 @@ get_proxy_for_iface (Device          *device,
 	g_signal_connect (G_OBJECT (proxy), "g-signal",
 			  G_CALLBACK (proxy_g_signal), client);
 
-	return proxy;
+	return g_object_ref (proxy);
 }
 
 static GVariant *
@@ -378,6 +378,7 @@ device_list_nodes (Device *device, BluetoothClient *client)
 				g_hash_table_insert (table, (gpointer) detectable_interfaces[i], GINT_TO_POINTER (status));
 			g_variant_unref (props);
 		}
+		g_object_unref (iface);
 	}
 
 	if (g_hash_table_size (table) == 0) {
@@ -524,6 +525,7 @@ add_device (Adapter         *adapter,
 		return;
 
 	if (path != NULL) {
+		ret = NULL;
 		device = device_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
 							G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES | G_DBUS_PROXY_FLAGS_DO_NOT_AUTO_START,
 							BLUEZ_SERVICE,
@@ -760,6 +762,7 @@ adapter_added (Manager         *manager,
 	const gchar *address, *name;
 	gboolean discovering, discoverable, powered;
 
+	variant = NULL;
 	adapter = adapter_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
 						  G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES | G_DBUS_PROXY_FLAGS_DO_NOT_AUTO_START,
 						  BLUEZ_SERVICE,
@@ -963,6 +966,7 @@ bluez_appeared_cb (GDBusConnection *connection,
 	g_signal_connect (G_OBJECT (priv->manager), "g-signal",
 			  G_CALLBACK (manager_g_signal), client);
 
+	variant = NULL;
 	manager_call_get_properties_sync (MANAGER (priv->manager), &variant, NULL, NULL);
 	if (variant != NULL) {
 		GVariant *v;
@@ -1648,6 +1652,7 @@ typedef struct {
 	GSimpleAsyncResult *simple;
 	/* used for disconnect */
 	GList *services;
+	Device *device;
 } ConnectData;
 
 static void
@@ -1662,9 +1667,12 @@ connect_callback (GDBusProxy   *proxy,
 	variant = g_dbus_proxy_call_finish (proxy, res, &error);
 	if (variant == NULL) {
 		retval = FALSE;
-		g_debug ("Connect failed: %s", error->message);
+		g_debug ("Connect failed for %s: %s",
+			 g_dbus_proxy_get_object_path (proxy), error->message);
 		g_error_free (error);
 	} else {
+		g_debug ("Connect succeeded for %s",
+			 g_dbus_proxy_get_object_path (proxy));
 		g_variant_unref (variant);
 		retval = TRUE;
 	}
@@ -1686,10 +1694,15 @@ disconnect_callback (GDBusProxy   *proxy,
 	GError *error = NULL;
 
 	if (conndata->services == NULL) {
-		retval = device_call_disconnect_finish (DEVICE (proxy), res, &error);
+		retval = device_call_disconnect_finish (conndata->device, res, &error);
 		if (retval == FALSE) {
-			g_debug ("Disconnect failed: %s", error->message);
+			g_debug ("Disconnect failed for %s: %s",
+				 g_dbus_proxy_get_object_path (G_DBUS_PROXY (conndata->device)),
+				 error->message);
 			g_error_free (error);
+		} else {
+			g_debug ("Disconnect succeeded for %s",
+				 g_dbus_proxy_get_object_path (G_DBUS_PROXY (conndata->device)));
 		}
 	} else {
 		GDBusProxy *service;
@@ -1699,15 +1712,22 @@ disconnect_callback (GDBusProxy   *proxy,
 		variant = g_dbus_proxy_call_finish (proxy, res, &error);
 		if (variant == NULL) {
 			retval = FALSE;
-			g_debug ("Disconnect failed: %s", error->message);
+			g_debug ("Disconnect failed for %s on %s: %s",
+				 g_dbus_proxy_get_object_path (proxy),
+				 g_dbus_proxy_get_interface_name (proxy),
+				 error->message);
 			g_error_free (error);
 		} else {
+			g_debug ("Disconnect succeeded for %s on %s",
+				 g_dbus_proxy_get_object_path (proxy),
+				 g_dbus_proxy_get_interface_name (proxy));
 			g_variant_unref (variant);
 			retval = TRUE;
 		}
+		g_object_unref (proxy);
 
 		client = (BluetoothClient *) g_async_result_get_source_object (G_ASYNC_RESULT (conndata->simple));
-		service = get_proxy_for_iface (DEVICE (proxy), conndata->services->data, client);
+		service = get_proxy_for_iface (DEVICE (conndata->device), conndata->services->data, client);
 		g_object_unref (client);
 
 		conndata->services = g_list_remove (conndata->services, conndata->services->data);
@@ -1721,8 +1741,6 @@ disconnect_callback (GDBusProxy   *proxy,
 				   (GAsyncReadyCallback) disconnect_callback,
 				   conndata);
 
-		g_object_unref (service);
-
 		return;
 	}
 
@@ -1730,6 +1748,7 @@ disconnect_callback (GDBusProxy   *proxy,
 	g_simple_async_result_complete_in_idle (conndata->simple);
 
 	g_object_unref (proxy);
+	g_clear_object (&conndata->device);
 	g_object_unref (conndata->simple);
 	g_free (conndata);
 }
@@ -1862,6 +1881,9 @@ bluetooth_client_connect_service (BluetoothClient     *client,
 
 		service = get_proxy_for_iface (DEVICE (proxy), iface_name, client);
 
+		g_debug ("Calling 'Connect' on interface %s for %s",
+			 iface_name, g_dbus_proxy_get_object_path (service));
+
 		g_dbus_proxy_call (G_DBUS_PROXY (service),
 				   "Connect",
 				   NULL,
@@ -1873,11 +1895,15 @@ bluetooth_client_connect_service (BluetoothClient     *client,
 	} else if (table != NULL) {
 		GDBusProxy *service;
 
+		conndata->device = g_object_ref (DEVICE (proxy));
 		conndata->services = g_hash_table_get_keys (table);
 		g_hash_table_unref (table);
 		conndata->services = g_list_sort (conndata->services, (GCompareFunc) rev_sort_services);
 
-		service = get_proxy_for_iface (DEVICE (proxy), conndata->services->data, client);
+		service = get_proxy_for_iface (conndata->device, conndata->services->data, client);
+
+		g_debug ("Calling 'Disconnect' on interface %s for %s",
+			 (char *) conndata->services->data, g_dbus_proxy_get_object_path (service));
 
 		conndata->services = g_list_remove (conndata->services, conndata->services->data);
 
@@ -1890,6 +1916,8 @@ bluetooth_client_connect_service (BluetoothClient     *client,
 				   (GAsyncReadyCallback) disconnect_callback,
 				   conndata);
 	} else if (table == NULL) {
+		g_debug ("Calling device_call_disconnect() for %s",
+			 g_dbus_proxy_get_object_path (proxy));
 		device_call_disconnect (DEVICE (proxy),
 					NULL,
 					(GAsyncReadyCallback) disconnect_callback,
