@@ -35,14 +35,6 @@ const gchar   *bluetooth_type_to_string (guint type);
 gboolean       bluetooth_verify_address (const char *bdaddr);
 const char    *bluetooth_uuid_to_string (const char *uuid);
 
-gboolean bluetooth_browse_address_finish (GObject *object,
-					  GAsyncResult *result,
-					  GError **error);
-void bluetooth_browse_address (GObject *object,
-			       const char *address,
-			       guint timestamp,
-			       GAsyncReadyCallback callback,
-			       gpointer user_data);
 void bluetooth_send_to_address (const char *address,
 				const char *alias);
 
